<template>
  <AdminLayout>
    <DashboardHeader>
      <DashboardTitle>{{ $t("app.admin.settings.appearance.title") }}</DashboardTitle>
    </DashboardHeader>
    <SettingsBody>
      <template v-if="appearanceSettingsFetch.hasErrors">
        <ErrorState />
      </template>
      <template v-else>
        <FormGroup
          :is-loading="appearanceSettingsFetch.isFetching"
          @submit="submit"
        >
          <AlertError v-if="form.errors && form.errors?.unknown">
            {{ form.errors.unknown }}
          </AlertError>
          <FormSection>
            <FormInput
              id="icon"
              :errors="form.errors.icon"
            >
              <FormLabel>{{ $t("app.admin.settings.appearance.form.icon") }}</FormLabel>
              <FormImage
                v-model="form.values.icon"
                name="icon"
                required
              />
            </FormInput>
            <FormInput
              id="icon"
              :errors="form.errors.background"
            >
              <FormLabel>{{ $t("app.admin.settings.appearance.form.background") }}</FormLabel>
              <FormImage
                v-model="form.values.background"
                name="background"
                required
              />
            </FormInput>
          </FormSection>
          <div>
            <FormSubmit
              :processing="form.isFetching"
              class="btn btn-black"
            >
              {{ $t("app.admin.settings.submit") }}
            </FormSubmit>
          </div>
        </FormGroup>
      </template>
    </SettingsBody>
  </AdminLayout>
</template>

<script lang="ts" setup>
import DashboardHeader from "@/js/contexts/shared/ui/components/dashboard/DashboardHeader.vue";
import DashboardTitle from "@/js/contexts/shared/ui/components/dashboard/DashboardTitle.vue";
import AdminLayout from "@/js/contexts/admin/shared/ui/layouts/AdminLayout.vue";
import SettingsBody from "@/js/contexts/admin/settings/ui/components/SettingsBody.vue";
import FormSection from "@/js/contexts/form/ui/components/FormSection.vue";
import FormSubmit from "@/js/contexts/form/ui/components/FormSubmit.vue";
import FormGroup from "@/js/contexts/form/ui/components/FormGroup.vue";
import FormLabel from "@/js/contexts/form/ui/components/FormLabel.vue";
import FormInput from "@/js/contexts/form/ui/components/FormInput.vue";
import FormImage from "@/js/contexts/form/ui/components/FormImage.vue";
import useForm from "@/js/contexts/shared/composables/useForm";
import AlertError from "@/js/contexts/shared/ui/components/alert/AlertError.vue";
import useFetch from "@/js/contexts/shared/composables/useFetch";
import ErrorState from "@/js/contexts/shared/ui/components/error/ErrorState.vue";
import useNotification from "@/js/contexts/shared/composables/useNotification";

type Response = { icon: string; background: string };

const { t } = useI18n();
const { successNotification } = useNotification();

useHead({
  title: t("app.admin.settings.appearance.title"),
});

const appearanceSettingsFetch = useFetch("/api/admin/settings/appearance", { isFetching: true });

const form = useForm({
  icon: "",
  background: "",
});

onMounted(() => {
  appearanceSettingsFetch.get<Response>().then((response) => {
    form.values.icon = response.data.icon;
    form.values.background = response.data.background;
    form.updatedValues();
  });
});

const submit = () => {
  form.post("/api/admin/settings/appearance", {
    onSuccess: () => successNotification(t("app.admin.settings.success")),
  });
};
</script>
